/*  These are all of the global variables used during accretion:  */

extern float anum;
extern planet_pointer planet_head;
extern double stellar_mass_ratio, stellar_luminosity_ratio, main_seq_life;
extern double age, r_ecosphere, r_greenhouse, radians_per_rotation;
extern int spin_resonance;

/* These are all of the function prototypes needed to compile successfully */

/* accrete.c */
void set_initial_conditions( double, double );
double stellar_dust_limit( double );
double innermost_planet( double );
double outermost_planet( double );
double inner_effect_limit( double, double, double );
double outer_effect_limit( double, double, double );
int dust_available( double, double );
void update_dust_lanes( double, double, double, double, double, double );
double collect_dust( double, double, double, double, dust_pointer );
double critical_limit( double, double, double );
void accrete_dust( double *, double, double, double, double, double );
void coalesce_planetesimals( double, double, double, double, double , double, double );
planet_pointer distribute_planetary_masses( double, double, double, double );
planet_pointer distribute_moon_masses( double, double, double, double, double );

/* display.c */
void display_system( void );

/* enviro.c */

double luminosity( double );
int orbital_zone( double );
double volume_radius( double , double );
double kothari_radius( double, double, int, int );
double empirical_density( double, double, int );
double volume_density( double, double );
double period( double, double, double );
double day_length( double, double, double, double, int );
int inclination( double );
double escape_vel( double, double );
double rms_vel( double, double );
double molecule_limit( double, double, double );
double acceleration(double mass, double radius );
double gravity( double );
int greenhouse( int, double, double );
double vol_inventory( double, double, double, double, int, int );
double pressure( double, double, double );
double boiling_point( double );
double hydrosphere_fraction( double, double );
double cloud_fraction( double, double, double, double );
double ice_fraction( double, double );
double eff_temp( double, double, double );
double green_rise( double, double, double );
double planet_albedo( double, double, double, double );
double opacity( double, double );
void iterate_surface_temp( planet_pointer * );

/* main.c */

void init( void );
void generate_stellar_system( void );
void main ( void );

/* utils.c */

double random_number ( double, double );
double about ( double, double );
double random_eccentricity ( void );
